==> PPDF_1_0.zip: PubMedPDF/language/english/main.php <==
<?php

define("_MD_PDF_A","Upload PDF file");
define("_MD_PDF_A_DESC","	Register by uploading PDF file which is named \"PMID.pdf\"");
define("_MD_PDF_B","Submit PMID only for later uploading");
define("_MD_PDF_B_DESC","Register by entering PMID<br>Even after registration, PDF file can be uploaded by \"Upload PDF file\"");
define("_MD_PDF_C","Automatic registraion");
define("_MD_PDF_C_DESC","Automatic registration by PDF files in the pdf file directory <br>It will require considerable time.");
define("_MD_PDF_D","Automatic registration");
define("_MD_PDF_D_DESC","Automatic registration by PMID list file (csv format)");
define("_MD_PDF_E","Export registered PMID list");
define("_MD_PDF_E_DESC","Export registered PMID list in csv format<br>This file can be used in \"Automatic registration (2)\"");
define("_MD_L1","without PDF file");
define("_MD_L2","with PDF file");
define("_MD_L3","all");
define("_MD_L4","only data which were registered by you.");
define("_MD_PDF_F","Remove");
define("_MD_PDF_F_DESC","Remove PMID registration");

define("_MD_WO_A","Bibliographic information");
define("_MD_JOUR_REG","Journal/Book Registration");
define("_MD_JOUR_EDIT","Journal/Bookqߦdit");
define("_MD_REMOVE_INFO","Remove registered information");
define("_MD_EDIT_INFO","Edit registered information");
define("_MD_REGISTER_AUTO","Automatic registration");
define("_MD_REGISTER_AUTOINFO","Registration by XML files in \"uploads_xml\" directory");
define("_MD_REG_RESULT","Registration result");

define("_MD_XML_DOWNLOAD","Download XML archive");
define("_MD_XML_DOWNLOAD_DESC","You can get XML files.");

define("_MD_FAVORITE_MKDIR","New Directory");
define("_MD_FAVORITE_DIRLIST","Directory List");
define("_MD_FAVORITE_DIRTOP","Directory Top");

define("_MD_NOTE","Note list");
define("_MD_NOTE_PRI","private");
define("_MD_NOTE_PUB","public");
define("_MD_NOTE_NEW","new");
define("_MD_NOTE_NEW2","add new note");
define("_MD_NOTE_CLOSE","close");
define("_MD_NOTE_ADDED","Above note has added.");
define("_MD_NOTE_EDIT","Note Edit");
define("_MD_NOTE_EDITED","Above note has changed.");
define("_MD_NOTE_EDIT_D","delete");
define("_MD_NOTE_EDIT_C","edit");
define("_MD_NOTE_PERMISSION_ERROR","You don't have the permission change this note.");
define("_MD_NOTE_NODATA_ERROR","Such data doesn't exist.");
define("_MD_NOTE_DEL","Do you delete this note?");
define("_MD_NOTE_DELETED","The note has deleted.");

define("_MD_SCUT","Make Shortcut");
define("_MD_SCUT_MADE","The shortcut to access this page has made.");

define("_MD_FAVO_ADD","Add Favorite");
define("_MD_FAVO_WHICHD","Which directory do you want to add this data?");
define("_MD_FAVO_ADDED","This data has added your favorite list.");

define("_MD_CHECK_ALL","Check All");
define("_MD_DELETE","Delete");
define("_MD_INSERTINTO","insert into");
define("_MD_ADD_BIBLIO","Add your bibliography list");

define("_MD_BIBLIO","Bibliography");
define("_MD_BIBLIO_EXIST","data exist on your bibliograpy list");
define("_MD_BIBLIO_EXPORT","show bibliograpy list");

define("_MD_PubMedSearch","PubMed Search");
define("_MD_PubMedSearch_unin_submit","Hide or show checked data.");
define("_MD_PubMedSearch_regist_submit","Register checked data.");

?>

==> PPDF_1_1.zip: PubMedPDF/language/english/main.php <==
<?php

define("_MD_PDF_A","Upload PDF file");
define("_MD_PDF_A_DESC","	Register by uploading PDF file which is named \"PMID.pdf\"");
define("_MD_PDF_B","Submit PMID only for later uploading");
define("_MD_PDF_B_DESC","Register by entering PMID<br>Even after registration, PDF file can be uploaded by \"Upload PDF file\"");
define("_MD_PDF_C","Automatic registraion");
define("_MD_PDF_C_DESC","Automatic registration by PDF files in the pdf file directory <br>It will require considerable time.");
define("_MD_PDF_D","Automatic registration");
define("_MD_PDF_D_DESC","Automatic registration by PMID list file (csv format)");
define("_MD_PDF_E","Export registered PMID list");
define("_MD_PDF_E_DESC","Export registered PMID list in csv format<br>This file can be used in \"Automatic registration (2)\"");
define("_MD_L1","without PDF file");
define("_MD_L2","with PDF file");
define("_MD_L3","all");
define("_MD_L4","only data which were registered by you.");
define("_MD_PDF_F","Remove");
define("_MD_PDF_F_DESC","Remove PMID registration");

define("_MD_WO_A","Bibliographic information");
define("_MD_JOUR_REG","Journal/Book Registration");
define("_MD_JOUR_EDIT","Journal/Book edit");
define("_MD_REMOVE_INFO","Remove registered information");
define("_MD_EDIT_INFO","Edit registered information");
define("_MD_REGISTER_AUTO","Automatic registration");
define("_MD_REGISTER_AUTOINFO","Registration by XML files in \"uploads_xml\" directory");
define("_MD_REG_RESULT","Registration result");

define("_MD_XML_DOWNLOAD","Download XML archive");
define("_MD_XML_DOWNLOAD_DESC","You can get XML files.");

define("_MD_FAVORITE_MKDIR","New Directory");
define("_MD_FAVORITE_DIRLIST","Directory List");
define("_MD_FAVORITE_DIRTOP","Directory Top");

define("_MD_NOTE","Note list");
define("_MD_NOTE_PRI","private");
define("_MD_NOTE_PUB","public");
define("_MD_NOTE_NEW","new");
define("_MD_NOTE_NEW2","add new note");
define("_MD_NOTE_CLOSE","close");
define("_MD_NOTE_ADDED","Above note has added.");
define("_MD_NOTE_EDIT","Note Edit");
define("_MD_NOTE_EDITED","Above note has changed.");
define("_MD_NOTE_EDIT_D","delete");
define("_MD_NOTE_EDIT_C","edit");
define("_MD_NOTE_PERMISSION_ERROR","You don't have the permission change this note.");
define("_MD_NOTE_NODATA_ERROR","Such data doesn't exist.");
define("_MD_NOTE_DEL","Do you delete this note?");
define("_MD_NOTE_DELETED","The note has deleted.");

define("_MD_SCUT","Make Shortcut");
define("_MD_SCUT_MADE","The shortcut to access this page has made.");

define("_MD_FAVO_ADD","Add Favorite");
define("_MD_FAVO_WHICHD","Which directory do you want to add this data?");
define("_MD_FAVO_ADDED","This data has added your favorite list.");

define("_MD_CHECK_ALL","Check All");
define("_MD_DELETE","Delete");
define("_MD_INSERTINTO","insert into");
define("_MD_ADD_BIBLIO","Add your bibliography list");

define("_MD_BIBLIO","Bibliography");
define("_MD_BIBLIO_EXIST","data exist on your bibliograpy list");
define("_MD_BIBLIO_EXPORT","show bibliograpy list");

define("_MD_PubMedSearch","PubMed Search");
define("_MD_PubMedSearch_unin_submit","Hide or show checked data.");
define("_MD_PubMedSearch_regist_submit","Register checked data.");

?>
